<?php

class BPGoogleSitemapGeneratorUI {

	/**
	 * The Sitemap Generator Object
	 *
	 * @var BPGoogleSitemapGenerator
	 */
	var $sg = null;
	
	function BPGoogleSitemapGeneratorUI(&$sitemapBuilder) {
		global $wp_version;
		$this->sg = &$sitemapBuilder;
	}
	
	function HtmlPrintBoxHeader($id, $title, $right = false) {
		?>
		<div id="<?php echo $id; ?>" class="postbox">
			<h3><?php echo $title ?></h3>
			<div class="inside">
		<?php
	}
	
	function HtmlPrintBoxFooter( $right = false) {
		?>
			</div>
		</div>
		<?php
	}
	
	/**
	 * Displays the option page
	 *
	 * @since 3.0
	 * @access public
	 * @author Arne Brachhold
	 */
	function HtmlShowOptionsPage() {
		global $wp_version;
		
		$snl = false; //SNL
		
		$this->sg->Initate();
			
		$message="";
		
		if(!empty($_REQUEST["bpsm_rebuild"])) { //Pressed Button: Rebuild Sitemap
			check_admin_referer('bp-sitemap');
			
			//Clear any outstanding build cron jobs
			if(function_exists('wp_clear_scheduled_hook')) wp_clear_scheduled_hook('bpsm_build_cron');
			
			if(isset($_GET["bpsm_do_debug"]) && $_GET["bpsm_do_debug"]=="true") {
				
				//Check again, just for the case that something went wrong before
				if(!current_user_can("administrator")) {
					echo '<p>Please log in as admin</p>';
					return;
				}
				
				$oldErr = error_reporting(E_ALL);
				$oldIni = ini_set("display_errors",1);

				echo '<div class="wrap">';
				echo '<h2>' .  __('BuddyPress Sitemap Generator', 'bp-sitemap') .  " " . $this->sg->GetVersion(). '</h2>';
				echo '<p>This is the debug mode of the BuddyPress Sitemap Generator. It will show all PHP notices and warnings as well as the internal logs, messages and configuration.</p>';
				echo '<p style="font-weight:bold; color:red; padding:5px; border:1px red solid; text-align:center;">DO NOT POST THIS INFORMATION ON PUBLIC PAGES LIKE SUPPORT FORUMS AS IT MAY CONTAIN PASSWORDS OR SECRET SERVER INFORMATION!</p>';
				echo "<h3>WordPress and PHP Information</h3>";
				echo '<p>WordPress ' . $GLOBALS['wp_version'] . ' with ' . ' DB ' . $GLOBALS['wp_db_version'] . ' on PHP ' . phpversion() . '</p>';
				echo '<p>Plugin version: ' . $this->sg->GetVersion() . ' (' . $this->sg->_svnVersion . ')';
				echo '<h4>Environment</h4>';
				echo "<pre>";
				$sc = $_SERVER;
				unset($sc["HTTP_COOKIE"]);
				print_r($sc);
				echo "</pre>";

				echo '<h4>Sitemap Config</h4>';
				echo "<pre>";
				print_r($this->sg->_options);
				echo "</pre>";
				echo '<h3>Errors, Warnings, Notices</h3>';
				echo '<div>';
				$status = $this->sg->BuildSitemap();
				echo '</div>';
				echo '<h3>MySQL Queries</h3>';
				if(defined('SAVEQUERIES') && SAVEQUERIES) {
					echo '<pre>';
					var_dump($GLOBALS['wpdb']->queries);
					echo '</pre>';
					
					$total = 0;
					foreach($GLOBALS['wpdb']->queries as $q) {
						$total+=$q[1];
					}
					echo '<h4>Total Query Time</h4>';
					echo '<pre>' . count($GLOBALS['wpdb']->queries) . ' queries in ' . round($total,2) . ' seconds.</pre>';
				} else {
					echo '<p>Please edit wp-db.inc.php in wp-includes and set SAVEQUERIES to true if you want to see the queries.</p>';
				}
				echo "<h3>Build Process Results</h3>";
				echo "<pre>";
				print_r($status);
				echo "</pre>";
				echo '<p>Done. <a href="' . wp_nonce_url($this->sg->GetBackLink() . "&bpsm_rebuild=true&bpsm_do_debug=true",'bp-sitemap') . '">Rebuild</a> or <a href="' . $this->sg->GetBackLink() . '">Return</a></p>';
				echo '<p style="font-weight:bold; color:red; padding:5px; border:1px red solid; text-align:center;">DO NOT POST THIS INFORMATION ON PUBLIC PAGES LIKE SUPPORT FORUMS AS IT MAY CONTAIN PASSWORDS OR SECRET SERVER INFORMATION!</p>';
				echo '</div>';
				@error_reporting($oldErr);
				@ini_set("display_errors",$oldIni);
				return;
			} else {
				$this->sg->BuildSitemap();
				$redirURL = $this->sg->GetBackLink() . '&bpsm_fromrb=true';
				
				//Redirect so the bpsm_rebuild GET parameter no longer exists.
				@header("location: " . $redirURL);
				//If there was already any other output, the header redirect will fail
				echo '<script type="text/javascript">location.replace("' . $redirURL . '");</script>';
				echo '<noscript><a href="' . $redirURL . '">Click here to continue</a></noscript>';
				exit;
			}
		} else if (!empty($_POST['bpsm_update'])) { //Pressed Button: Update Config
			check_admin_referer('bp-sitemap');
			
			if(isset($_POST['bpsm_b_style']) && $_POST['bpsm_b_style'] == $this->sg->getDefaultStyle()) {
				$_POST['bpsm_b_style_default'] = true;
				$_POST['bpsm_b_style'] = '';
			}
			
			foreach($this->sg->_options as $k=>$v) {
				
				//Check vor values and convert them into their types, based on the category they are in
				if(!isset($_POST[$k])) $_POST[$k]=""; // Empty string will get false on 2bool and 0 on 2float
				
				//Options of the category "Basic Settings" are boolean, except the filename and the autoprio provider
				if(substr($k,0,7)=="bpsm_b_") {
					if($k=="bpsm_b_filename" || $k=="bpsm_b_fileurl_manual" || $k=="bpsm_b_filename_manual" || $k=="bpsm_b_manual_key" || $k == "bpsm_b_yahookey"  || $k == "sm_b_style" || $k == "bpsm_b_memory") {
						if($k=="bpsm_b_filename_manual" && strpos($_POST[$k],"\\")!==false){
							$_POST[$k]=stripslashes($_POST[$k]);
						}
						
						$this->sg->_options[$k]=(string) $_POST[$k];
					} else if($k=="bpsm_b_location_mode") {
						$tmp=(string) $_POST[$k];
						$tmp=strtolower($tmp);
						if($tmp=="auto" || $tmp="manual") $this->sg->_options[$k]=$tmp;
						else $this->sg->_options[$k]="auto";
					} else if($k== "bpsm_i_install_date") {
						if($this->sg->GetOption('i_install_date')<=0) $this->sg->_options[$k] = time();
					} else {
						$this->sg->_options[$k]=(bool) $_POST[$k];

					}
					
				}
			}
			
			if($this->sg->SaveOptions()) $message.=__('Configuration updated', 'bp-sitemap') . "<br />";
			else $message.=__('Error while saving options', 'bp-sitemap') . "<br />";
			
		} else if(!empty($_POST["bpsm_reset_config"])) { //Pressed Button: Reset Config
			check_admin_referer('bp-sitemap');
			$this->sg->InitOptions();
			$this->sg->SaveOptions();
			
			$message.=__('The default configuration was restored.','bp-sitemap');
		}
		
		//Print out the message to the user, if any
		if($message!="") {
			?>
			<div class="updated"><strong><p><?php
			echo $message;
			?></p></strong></div><?php
		}
		
		if(function_exists("wp_next_scheduled")) {
			$next = wp_next_scheduled('bpsm_build_cron');
			if($next) {
				$diff = (time()-$next)*-1;
				if($diff <= 0) {
					$diffMsg = __('Your sitemap is being refreshed at the moment. Depending on your buddypress size this might take some time!<br /><small>Due to limitations of the WordPress scheduler, it might take another 60 seconds until the build process is actually started.</small>','bp-sitemap');
				} else {
					$diffMsg = str_replace("%s",$diff,__('Your sitemap will be refreshed in %s seconds. Depending on your buddypress size this might take some time!','bp-sitemap'));
				}
				?>
				<div class="updated">
					<strong><p><?php echo $diffMsg ?></p></strong>
					<div style="clear:right;"></div>
				</div>
				<?php
			}
		}
		
		?>
		<style type="text/css">
		
		li.bpsm_hint {
			color:green;
		}
		
		li.bpsm_optimize {
			color:orange;
		}
		
		li.bpsm_error {
			color:red;
		}
		
		input.bpsm_warning:hover {
			background: #ce0000;
			color: #fff;
		}
		
		a.bpsm_button {
			padding:4px;
			display:block;
			padding-left:25px;
			background-repeat:no-repeat;
			background-position:5px 50%;
			text-decoration:none;
			border:none;
		}
		
		a.bpsm_button:hover {
			border-bottom-width:1px;
		}

		div.bpsm-update-nag p {
			margin:5px;
		}
		
		.bpsm-padded .inside {
			margin:12px!important;
		}
		.bpsm-padded .inside ul {
			margin:6px 0 12px 0;
		}
		
		.bpsm-padded .inside input {
			padding:1px;
			margin:0;
		}
		</style>
		
		<div class="wrap" id="bpsm_div">
			<form method="post" action="<?php echo $this->sg->GetBackLink() ?>">
				<h2><?php _e('BuddyPress Sitemap Generator', 'bp-sitemap'); echo " " . $this->sg->GetVersion() ?> </h2>
				<?php
				if(get_option('blog_public')!=1) {
					?><div class="error"><p><?php echo str_replace("%s","options-privacy.php",__('Your blog is currently blocking search engines! Visit the <a href="%s">privacy settings</a> to change this.','bp-sitemap')); ?></p></div><?php
				}
				if (BP_SITEMAP_EXPECTED_VERSION != BP_VERSION || (bp_is_active( 'groups' ) && BP_SITEMAP_EXPECTED_GROUPS_DB_VERSION != BP_GROUPS_DB_VERSION) || (bp_is_active( 'xprofile' ) && BP_SITEMAP_EXPECTED_XPROFILE_DB_VERSION != BP_XPROFILE_DB_VERSION) || (bp_is_active( 'activity' ) && BP_SITEMAP_EXPECTED_ACTIVITY_DB_VERSION != BP_ACTIVITY_DB_VERSION) || (bp_is_active( 'friends' ) && BP_SITEMAP_EXPECTED_FRIENDS_DB_VERSION != BP_FRIENDS_DB_VERSION) ) {
					?><div class="error"><p><?php _e('Unpredictable results may occur. Database or BuddyPress version out of sync on what Sitemap generator was tested against','bp-sitemap'); ?></p></div><?php
				}
				?>
			
				<div id="advancedstuff" class="dbx-group" >
					
					<!-- Rebuild Area -->
					<?php
						$status = &BPGoogleSitemapGeneratorStatus::Load();
						$head = __('The sitemap wasn\'t generated yet.','bp-sitemap');
						if($status != null) {
							$st=$status->GetStartTime();
							$head=str_replace("%date%",date(get_option('date_format'),$st) . " " . date(get_option('time_format'),$st),__("Result of the last build process, started on %date%.",'bp-sitemap'));
						}
			
						$this->HtmlPrintBoxHeader('bpsm_rebuild',$head); ?>
						<ul>
							<?php
	

							if($status == null) {
								echo "<li>" . str_replace("%s",wp_nonce_url($this->sg->GetBackLink() . "&bpsm_rebuild=true&noheader=true",'bp-sitemap'),__('The sitemap wasn\'t built yet. <a href="%s">Click here</a> to build it the first time.','bp-sitemap')) . "</li>";
							}  else {
								if($status->_endTime !== 0) {
									if($status->_usedXml) {
										if($status->_xmlSuccess) {
											$ft = is_readable($status->_xmlPath)?filemtime($status->_xmlPath):false;
											if($ft!==false) echo "<li>" . str_replace("%url%",$status->_xmlUrl,str_replace("%date%",date(get_option('date_format'),$ft) . " " . date(get_option('time_format'),$ft),__("Your <a href=\"%url%\">sitemap</a> was last built on <b>%date%</b>.",'bp-sitemap'))) . "</li>";
											else echo "<li class=\"bpsm_error\">" . __("The last build succeeded, but the file was deleted later or can't be accessed anymore. Did you move your blog to another server or domain?",'bp-sitemap') . "</li>";
										} else {
											echo "<li class=\"bpsm_error\">" . __("There was a problem writing your sitemap file. Make sure the file exists and is writable. <a href=\"%url%\">Learn more</a>",'bp-sitemap') . "</li>";
										}
									}
									
									if($status->_usedGoogle) {
										if($status->_gooogleSuccess) {
											echo "<li>" .__("Google was <b>successfully notified</b> about changes.",'bp-sitemap'). "</li>";
											$gt = $status->GetGoogleTime();
											if($gt>4) {
												echo "<li class=\bpsm_optimize\">" . str_replace("%time%",$gt,__("It took %time% seconds to notify Google, maybe you want to disable this feature to reduce the building time.",'bp-sitemap')) . "</li>";
											}
										} else {
											echo "<li class=\"bpsm_error\">" . str_replace("%s",wp_nonce_url($this->sg->GetBackLink() . "&bpsm_ping_service=google&noheader=true",'bp-sitemap'),__('There was a problem while notifying Google. <a href="%s">View result</a>','bp-sitemap')) . "</li>";
										}
									}
									
									if($status->_usedYahoo) {
										if($status->_yahooSuccess) {
											echo "<li>" .__("YAHOO was <b>successfully notified</b> about changes.",'bp-sitemap'). "</li>";
											$yt = $status->GetYahooTime();
											if($yt>4) {
												echo "<li class=\bpsm_optimize\">" . str_replace("%time%",$yt,__("It took %time% seconds to notify YAHOO, maybe you want to disable this feature to reduce the building time.",'bp-sitemap')) . "</li>";
											}
										} else {
											echo "<li class=\"bpsm_error\">" . str_replace("%s",wp_nonce_url($this->sg->GetBackLink() . "&bpsm_ping_service=yahoo&noheader=true",'bp-sitemap'),__('There was a problem while notifying YAHOO. <a href="%s">View result</a>','bp-sitemap')) . "</li>";
										}
									}
									
									if($status->_usedMsn) {
										if($status->_msnSuccess) {
											echo "<li>" .__("Bing was <b>successfully notified</b> about changes.",'bp-sitemap'). "</li>";
											$at = $status->GetMsnTime();
											if($at>4) {
												echo "<li class=\bpsm_optimize\">" . str_replace("%time%",$at,__("It took %time% seconds to notify Bing, maybe you want to disable this feature to reduce the building time.",'bp-sitemap')) . "</li>";
											}
										} else {
											echo "<li class=\"bpsm_error\">" . str_replace("%s",wp_nonce_url($this->sg->GetBackLink() . "&bpsm_ping_service=msn&noheader=true",'bp-sitemap'),__('There was a problem while notifying Bing. <a href="%s">View result</a>','bp-sitemap')) . "</li>";
										}
									}
									
									if($status->_usedAsk) {
										if($status->_askSuccess) {
											echo "<li>" .__("Ask.com was <b>successfully notified</b> about changes.",'bp-sitemap'). "</li>";
											$at = $status->GetAskTime();
											if($at>4) {
												echo "<li class=\bpsm_optimize\">" . str_replace("%time%",$at,__("It took %time% seconds to notify Ask.com, maybe you want to disable this feature to reduce the building time.",'bp-sitemap')) . "</li>";
											}
										} else {
											echo "<li class=\"bpsm_error\">" . str_replace("%s",wp_nonce_url($this->sg->GetBackLink() . "&bpsm_ping_service=ask&noheader=true",'bp-sitemap'),__('There was a problem while notifying Ask.com. <a href="%s">View result</a>','bp-sitemap')) . "</li>";
										}
									}
									
									$et = $status->GetTime();
									$mem = $status->GetMemoryUsage();
									
									if($mem > 0) {
										echo "<li>" .str_replace(array("%time%","%memory%"),array($et,$mem),__("The building process took about <b>%time% seconds</b> to complete and used %memory% MB of memory.",'bp-sitemap')). "</li>";
									} else {
										echo "<li>" .str_replace("%time%",$et,__("The building process took about <b>%time% seconds</b> to complete.",'bp-sitemap')). "</li>";
									}
									
									if(!$status->_hasChanged) {
										echo "<li>" . __("The content of your sitemap <strong>didn't change</strong> since the last time so the files were not written and no search engine was pinged.",'bp-sitemap'). "</li>";
									}
													
								} else {
									if($this->sg->GetOption("b_auto_delay")) {
										$st = ($status->GetStartTime() - time()) * -1;
										//If the building process runs in background and was started within the last 45 seconds, the sitemap might not be completed yet...
										if($st < 45) {
											echo '<li class="">'. __("The building process might still be active! Reload the page in a few seconds and check if something has changed.",'bp-sitemap') . '</li>';
										}
									}
									echo '<li class="bpsm_error">'. __("The last run didn't finish! Maybe you can raise the memory or time limit for PHP scripts. <a href=\"%url%\">Learn more</a>",'bp-sitemap') . '</li>';
									if($status->_memoryUsage > 0) {
										echo '<li class="bpsm_error">'. str_replace(array("%memused%","%memlimit%"),array($status->GetMemoryUsage(),ini_get('memory_limit')),__("The last known memory usage of the script was %memused%MB, the limit of your server is %memlimit%.",'bp-sitemap')) . '</li>';
									}
									
									if($status->_lastTime > 0) {
										echo '<li class="bpsm_error">'. str_replace(array("%timeused%","%timelimit%"),array($status->GetLastTime(),ini_get('max_execution_time')),__("The last known execution time of the script was %timeused% seconds, the limit of your server is %timelimit% seconds.",'bp-sitemap')) . '</li>';
									}
									
									if($status->GetLastPost() > 0) {
										echo '<li class="bpsm_optimize">'. str_replace("%lastpost%",$status->GetLastPost(),__("The script stopped around post number %lastpost% (+/- 100)",'bp-sitemap')) . '</li>';
									}
								}
								echo "<li>" . str_replace("%s",wp_nonce_url($this->sg->GetBackLink() . "&bpsm_rebuild=true&noheader=true",'bp-sitemap'),__('If you changed something on your server or blog, you should <a href="%s">rebuild the sitemap</a> manually.','bp-sitemap')) . "</li>";
							}
							echo "<li>" . str_replace("%d",wp_nonce_url($this->sg->GetBackLink() . "&bpsm_rebuild=true&bpsm_do_debug=true",'bp-sitemap'),__('If you encounter any problems with the build process you can use the <a href="%d">debug function</a> to get more information.','bp-sitemap')) . "</li>";
							?>

						</ul>
					<?php $this->HtmlPrintBoxFooter(); ?>
						
					<!-- Basic Options -->
					<?php $this->HtmlPrintBoxHeader('bpsm_basic_options',__('Basic Options', 'bp-sitemap')); ?>
					
						<b><?php _e('Sitemap files:','bp-sitemap'); ?></b>
						<ul>
							<li>
								<label for="bpsm_b_xml">
									<input type="checkbox" id="bpsm_b_xml" name="bpsm_b_xml" <?php echo ($this->sg->GetOption("b_xml")==true?"checked=\"checked\"":"") ?> />
									<?php _e('Write a normal XML file (your filename)', 'bp-sitemap') ?>
								</label>
							</li>
							<li>
								<label for="bpsm_b_gzip">
									<input type="checkbox" id="bpsm_b_gzip" name="bpsm_b_gzip" <?php if(function_exists("gzencode")) { echo ($this->sg->GetOption("b_gzip")==true?"checked=\"checked\"":""); } else echo "disabled=\"disabled\"";  ?> />
									<?php _e('Write a gzipped file (your filename + .gz)', 'bp-sitemap') ?>
								</label>
							</li>
						</ul>
						<b><?php _e('Building mode:','bp-sitemap'); ?></b>
						<ul>
							<li>
								<label for="bpsm_b_manual_enabled">
									<input type="hidden" name="bpsm_b_manual_key" value="<?php echo $this->sg->GetOption("b_manual_key"); ?>" />
									<input type="checkbox" id="bpsm_b_manual_enabled" name="bpsm_b_manual_enabled" <?php echo ($this->sg->GetOption("b_manual_enabled")==true?"checked=\"checked\"":"") ?> />
									<?php _e('Enable manual sitemap building via GET Request', 'bp-sitemap') ?>
								</label>
								<a href="javascript:void(document.getElementById('bpsm_manual_help').style.display='');">[?]</a>
								<span id="bpsm_manual_help" style="display:none;"><br />
								<?php echo str_replace("%1",trailingslashit(get_bloginfo('siteurl')) . "?bpsm_command=build&amp;bpsm_key=" . $this->sg->GetOption("b_manual_key"),__('This will allow you to refresh your sitemap. Use the following URL to start the process: <a href="%1">%1</a> Please check the result box above to see if sitemap was successfully built.', 'bp-sitemap')); ?>
								</span>
							</li>
						</ul>
						<b><?php _e('Update notification:','bp-sitemap'); ?></b>
						<ul>
							<li>
								<input type="checkbox" id="bpsm_b_ping" name="bpsm_b_ping" <?php echo ($this->sg->GetOption("b_ping")==true?"checked=\"checked\"":"") ?> />
								<label for="bpsm_b_ping"><?php _e('Notify Google about updates of your Blog', 'bp-sitemap') ?></label><br />
								<small><a href="">Google Webmaster Tools</a></small>
							</li>
							<li>
								<input type="checkbox" id="bpsm_b_pingmsn" name="bpsm_b_pingmsn" <?php echo ($this->sg->GetOption("b_pingmsn")==true?"checked=\"checked\"":"") ?> />
								<label for="bpsm_b_pingmsn"><?php _e('Notify Bing (formerly MSN Live Search) about updates of your Blog', 'bp-sitemap') ?></label><br />
								<small><a href="">Bing Webmaster Tools</a></small>
							</li>
							<li>
								<input type="checkbox" id="bpsm_b_pingask" name="bpsm_b_pingask" <?php echo ($this->sg->GetOption("b_pingask")==true?"checked=\"checked\"":"") ?> />
								<label for="bpsm_b_pingask"><?php _e('Notify Ask.com about updates of your Blog', 'bp-sitemap') ?></label><br />
								<small><?php _e('No registration required.','bp-sitemap'); ?></small>
							</li>
							<li>
								<input type="checkbox" id="bpsm_b_pingyahoo" name="bpsm_b_pingyahoo" <?php echo ($this->sg->GetOption("b_pingyahoo")==true?"checked=\"checked\"":"") ?> />
								<label for="bpsm_b_pingyahoo"><?php _e('Notify YAHOO about updates of your Blog', 'bp-sitemap') ?></label><br />
								<label for="bpsm_b_yahookey"><?php _e('Your Application ID:', 'bp-sitemap') ?> <input type="text" name="bpsm_b_yahookey" id="bpsm_b_yahookey" value="<?php echo $this->sg->GetOption("b_yahookey"); ?>" /></label><br />
								<small><a href="http://developer.yahoo.net/about/">Web Services by Yahoo! - Request API Key</a></small>
							</li>
						</ul>
						<b><?php _e('Advanced options:','bp-sitemap'); ?></b>
						<ul>
							<li>
								<label for="bpsm_b_memory"><?php _e('Try to increase the memory limit to:', 'bp-sitemap') ?> <input type="text" name="bpsm_b_memory" id="bpsm_b_memory" style="width:40px;" value="<?php echo $this->sg->GetOption("b_memory"); ?>" /></label> (<?php echo htmlspecialchars(__('e.g. "4M", "16M"', 'bp-sitemap')); ?>)
							</li>
							<li>
								<label for="bpsm_b_time"><?php _e('Try to increase the execution time limit to:', 'bp-sitemap') ?> <input type="text" name="bpsm_b_time" id="bpsm_b_time" style="width:40px;" value="<?php echo ($this->sg->GetOption("b_time")===-1?'':$this->sg->GetOption("b_time")); ?>" /></label> (<?php echo htmlspecialchars(__('in seconds, e.g. "60" or "0" for unlimited', 'bp-sitemap')) ?>)
							</li>
							<li>
								<?php $useDefStyle = ($this->sg->GetDefaultStyle() && $this->sg->GetOption('b_style_default')===true); ?>
								<label for="sm_b_style"><?php _e('Include a XSLT stylesheet:', 'sitemap') ?> <input <?php echo ($useDefStyle?'disabled="disabled" ':'') ?> type="text" name="sm_b_style" id="sm_b_style"  value="<?php echo $this->sg->GetOption("b_style"); ?>" /></label>
								(<?php _e('Full or relative URL to your .xsl file', 'sitemap') ?>) <?php if($this->sg->GetDefaultStyle()): ?><label for="sm_b_style_default"><input <?php echo ($useDefStyle?'checked="checked" ':'') ?> type="checkbox" id="sm_b_style_default" name="sm_b_style_default" onclick="document.getElementById('sm_b_style').disabled = this.checked;" /> <?php _e('Use default', 'sitemap') ?> <?php endif; ?>
							</li>
							<li>
								<label for="bpsm_b_safemode">
									<?php $forceSafeMode = (floatval($wp_version)<2.2); ?>
									<input type="checkbox" <?php if($forceSafeMode):?>disabled="disabled"<?php endif; ?> id="bpsm_b_safemode" name="bpsm_b_safemode" <?php echo ($this->sg->GetOption("b_safemode")==true||$forceSafeMode?"checked=\"checked\"":""); ?> />
									<?php _e('Enable MySQL standard mode. Use this only if you\'re getting MySQL errors. (Needs much more memory!)', 'bp-sitemap') ?>
								</label>
							</li>
							<li>
								<label for="bpsm_b_auto_delay">
									<input type="checkbox"  id="bpsm_b_auto_delay" name="bpsm_b_auto_delay" <?php echo ($this->sg->GetOption("b_auto_delay")==true&&!$forceDirect?"checked=\"checked\"":""); ?> />
									<?php _e('Build the sitemap in a background process', 'bp-sitemap') ?>
								</label>
							</li>
							<li>
								<label for="bpsm_b_last_activity">
									<input type="checkbox"  id="bpsm_b_last_activity" name="bpsm_b_last_activity" <?php echo ($this->sg->GetOption("b_last_activity")==true&&!$forceDirect?"checked=\"checked\"":""); ?> />
									<?php _e('Enable last_activity timestamp for profiles and groups (Needs much more memory!)', 'bp-sitemap') ?>
								</label>
							</li>
						</ul>
						
					<?php $this->HtmlPrintBoxFooter(); ?>
					

					<!-- Location Options -->
					<?php $this->HtmlPrintBoxHeader('bpsm_location',__('Location of your sitemap file - IMPORTANT - !!!UNIQUE JUST FOR BUDDYPRESS!!!', 'bp-sitemap')); ?>
		
						<div>
							<b><label for="bpsm_location_useauto"><input type="radio" id="bpsm_location_useauto" name="bpsm_b_location_mode" value="auto" <?php echo ($this->sg->GetOption("b_location_mode")=="auto"?"checked=\"checked\"":"") ?> /> <?php _e('Automatic detection','bp-sitemap') ?></label></b>
							<ul>
								<li>
									<label for="bpsm_b_filename">
										<?php _e('Filename of the sitemap file', 'bp-sitemap') ?>
										<input type="text" id="bpsm_b_filename" name="bpsm_b_filename" value="<?php echo $this->sg->GetOption("b_filename"); ?>" />
									</label><br />
									<?php _e('Detected Path', 'bp-sitemap') ?>: <?php echo $this->sg->getXmlPath(true); ?><br /><?php _e('Detected URL', 'bp-sitemap') ?>: <a href="<?php echo $this->sg->getXmlUrl(true); ?>"><?php echo $this->sg->getXmlUrl(true); ?></a>
								</li>
							</ul>
						</div>
						<div>
							<b><label for="bpsm_location_usemanual"><input type="radio" id="bpsm_location_usemanual" name="bpsm_b_location_mode" value="manual" <?php echo ($this->sg->GetOption("b_location_mode")=="manual"?"checked=\"checked\"":"") ?>  /> <?php _e('Custom location','bp-sitemap') ?></label></b>
							<ul>
								<li>
									<label for="bpsm_b_filename_manual">
										<?php _e('Absolute or relative path to the sitemap file, including name.','bp-sitemap');
										echo "<br />";
										_e('Example','bp-sitemap');
										echo ": /var/www/htdocs/wordpress/bp-sitemap.xml"; ?><br />
										<input style="width:70%" type="text" id="bpsm_b_filename_manual" name="bpsm_b_filename_manual" value="<?php echo (!$this->sg->GetOption("b_filename_manual")?$this->sg->getXmlPath():$this->sg->GetOption("b_filename_manual")); ?>" />
									</label>
								</li>
								<li>
									<label for="bpsm_b_fileurl_manual">
										<?php _e('Complete URL to the sitemap file, including name.','bp-sitemap');
										echo "<br />";
										_e('Example','bp-sitemap');
										echo ": http://www.yourdomain.com/bp-sitemap.xml"; ?><br />
										<input style="width:70%" type="text" id="bpsm_b_fileurl_manual" name="bpsm_b_fileurl_manual" value="<?php echo (!$this->sg->GetOption("b_fileurl_manual")?$this->sg->getXmlUrl():$this->sg->GetOption("b_fileurl_manual")); ?>" />
									</label>
								</li>
							</ul>
						</div>
						
					<?php $this->HtmlPrintBoxFooter(); ?>
					
					
					</div>
					<div>
						<p class="submit">
							<?php wp_nonce_field('bp-sitemap') ?>
							<input type="submit" name="bpsm_update" value="<?php _e('Update options', 'bp-sitemap'); ?>" />
							<input type="submit" onclick='return confirm("Do you really want to reset your configuration?");' class="bpsm_warning" name="bpsm_reset_config" value="<?php _e('Reset options', 'bp-sitemap'); ?>" />
						</p>
					</div>

			</form>
		</div>
		<?php
	}
}

